@@ -528,6 +528,13 @@ gpm_manager_notify (GpmManager *manager, NotifyNotification **notification_class
 	g_signal_connect (notification, "closed", G_CALLBACK (gpm_manager_notification_closed_cb), notification_class);
 	g_debug ("notification %p: %s : %s", notification, title, message);
 
+	/* non-urgent notifications are transient */
+	if (urgency != NOTIFY_URGENCY_CRITICAL) {
+		notify_notification_set_hint (notification,
+					      "transient",
+					      g_variant_new_boolean (TRUE));
+	}
+
 	/* try to show */
 	ret = notify_notification_show (notification, &error);
 	if (!ret) {
@@ -900,27 +907,62 @@ gpm_manager_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmManager *manage
 static void
 gpm_manager_lid_button_pressed (GpmManager *manager, gboolean pressed)
 {
+	const gchar *description;
+	const gchar *policy_key;
+	GpmActionPolicy policy;
+
 	if (pressed)
 		gpm_manager_play (manager, GPM_MANAGER_SOUND_LID_CLOSE, FALSE);
 	else
 		gpm_manager_play (manager, GPM_MANAGER_SOUND_LID_OPEN, FALSE);
 
+	/* we turn the lid dpms back on unconditionally */
 	if (pressed == FALSE) {
-		/* we turn the lid dpms back on unconditionally */
 		gpm_manager_unblank_screen (manager, NULL);
 		return;
 	}
 
+	/* we have different settings depending on AC state */
 	if (!manager->priv->on_battery) {
-		g_debug ("Performing AC policy");
-		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_LID_AC,
-					    "Lid closed on AC power.");
-		return;
+		policy_key = GSD_SETTINGS_BUTTON_LID_AC;
+		description = "Lid closed on AC power";
+	} else {
+		policy_key = GSD_SETTINGS_BUTTON_LID_BATT;
+		description = "Lid closed on battery power";
 	}
 
-	g_debug ("Performing battery policy");
-	gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_LID_BATT,
-				    "Lid closed on battery power.");
+	/* check that on systems that would meld when the lid is closed
+	 * and not asleep we set a better policy option */
+	policy = g_settings_get_enum (manager->priv->settings_gsd,
+				      policy_key);
+	if (policy != GPM_ACTION_POLICY_SUSPEND &&
+	    policy != GPM_ACTION_POLICY_HIBERNATE) {
+#if UP_CHECK_VERSION(0,9,9)
+		if (up_client_get_lid_force_sleep (manager->priv->up_client)) {
+			g_warning ("to prevent damage, %s is now forced to 'suspend'",
+				   policy_key);
+			g_settings_set_enum (manager->priv->settings_gsd,
+					     policy_key,
+					     GPM_ACTION_POLICY_SUSPEND);
+		}
+#else
+		g_warning ("Laptop may melt if lid is closed. "
+			   "Update UPower and rebuild to find out!");
+#endif
+	}
+
+#if UP_CHECK_VERSION(0,9,8)
+	/* are we docked? */
+	if (up_client_get_is_docked (manager->priv->client)) {
+		g_debug ("ignoring lid closed action because we are docked");
+		return;
+	}
+#endif
+
+	/* do action */
+	gpm_manager_perform_policy (manager,
+				    policy_key,
+				    description);
 }
 
 static void
@@ -2009,8 +2051,9 @@ gpm_manager_device_to_variant_blob (UpDevice *device)
 	GVariant *value;
 	GIcon *icon;
 	gchar *device_icon;
+	const gchar *object_path;
 
-	icon = gpm_upower_get_device_icon (device, FALSE);
+	icon = gpm_upower_get_device_icon (device, TRUE);
 	device_icon = g_icon_to_string (icon);
 	g_object_get (device,
 		      "kind", &kind,
@@ -2026,9 +2069,14 @@ gpm_manager_device_to_variant_blob (UpDevice *device)
 	else if (state == UP_DEVICE_STATE_CHARGING)
 		time_state = time_full;
 
+	/* get an object path, even for the composite device */
+	object_path = up_device_get_object_path (device);
+	if (object_path == NULL)
+		object_path = "/org/gnome/PowerManager";
+
 	/* format complex object */
 	value = g_variant_new ("(susdut)",
-			       up_device_get_object_path (device),
+			       object_path,
 			       kind,
 			       device_icon,
 			       percentage,
@@ -2099,10 +2147,6 @@ gpm_manager_dbus_method_call (GDBusConnection *connection,
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
-	if (tuple != NULL)
-		g_variant_unref (tuple);
-	if (value != NULL)
-		g_variant_unref (value);
 }
 
 /**
